@@ -21,9 +21,9 @@ if ($file eq '') {
   exit;
 }
 
-my $dbusername = 'root';
-my $dbpassword = 'rootpass';
-my $dbh = DBI->connect("DBI:mysql:radius",$dbusername, $dbpassword) || die "Could not connect to radius database as $dbusername\n";
+my $dbusername = "root";
+my $dbpassword = "rootpass";
+my $dbh = DBI->connect("DBI:mysql:radius",$dbusername, $dbpassword) || die "Cound not connect to radius database as $dbusername\n";
 
 open(DICT, $file) || die "Cannot open $file for read\n";
 
@@ -40,7 +40,7 @@ while (<DICT>) {
 
   ($dummystr, $namestr, $valstr, $typestr, $vendorstr) = split(/\s+/);
  
-  if ($dummystr =~ 'ATTRIB') {
+  if ($dummystr eq 'ATTRIBUTE') {
      $sql = "INSERT INTO dictionary VALUES \(\"\",\"$dummystr\",\"$namestr\",\"$valstr\",\"$typestr\",\"$vendorstr\"\)";
   } elsif ($dummystr eq 'VALUE') {
      $sql = "INSERT INTO dictionary VALUES \(\"\",\"$dummystr\",\"$namestr\",\"$valstr\",\"$typestr\",\"\"\)";
