@@ -15,8 +15,8 @@ use DBI;
 use strict;
 use Getopt::Std;
 
-my $username = 'root';
-my $password = 'rootpass';
+my $username = "root";
+my $password = "rootpass";
 
 
 my %opts;
@@ -44,7 +44,7 @@ my $i = 0;
 my $sql;
 if ($nas eq 'ALL') {
    if ($fixdb) {
-      $sth = $dbh->do("UPDATE radacct SET AcctStartTime =  from_unixtime(unix_timestamp(AcctStopTime) - AcctSessionTime) WHERE AcctStartTime = 0");
+      $sth = $dbh->do("UPDATE radacct SET AcctStartTime =  from_unixtime\(unix_timestamp\(AcctStopTime\) - AcctSessionTime\) WHERE AcctStartTime = 0");
    }
    $sql = "SELECT * FROM radacct WHERE AcctStopTime = 0";
 } else {
@@ -57,8 +57,8 @@ $sth = $dbh->prepare($sql);
 $sth->execute;
 while (my @data = $sth->fetchrow_array) {
 
-  print "Checking NAS $data[4] (port $data[5]) for user $data[2] with sessionid $data[1]\n";
-  if (system("checkrad livingston $data[4] $data[5] $data[2] $data[1]")) {
+  print "Checking NAS $data[3] (port $data[4]) for user $data[2] with sessionid $data[1]\n";
+  if (system("checkrad livingston $data[3] $data[4] $data[2] $data[1]")) {
      print "Yes, $data[2] is logged in now\n";
   } else {
      $i++;
