@@ -10,44 +10,29 @@
 #
 # Returns:	0 = no duplicate, 1 = duplicate, >1 = error.
 #
-# Version:	@(#)checkrad.pl  1.22  08-Mai-2000  miquels@cistron.nl
+# Version:	@(#)checkrad.pl  1.16  12-May-1999  miquels@cistron.nl
 #
 #		livingston_snmp  1.1	Author: miquels@cistron.nl
 #		portslave_finger 1.0	Author: miquels@cistron.nl
 #		max40xx_finger	 1.0	Author: costa@mdi.ca
-#		max40xx_snmp  	 1.0	Author: blaz@gold.amis.net
-#		ascend_snmp      1.1    Author: blaz@amis.net
 #		computone_finger 1.1	Author: costa@mdi.ca
 #		sub tc_tccheck	 1.1	Author: alexisv@compass.com.ph
-#		cyclades_telnet	 1.2	Author: accdias@sst.com.br
-#		patton_snmp	 1.0	Author: accdias@sst.com.br
-#		digitro_rusers	 1.1	Author: accdias@sst.com.br
-#		cyclades_snmp	 1.0	Author: accdias@sst.com.br
+#		pathras_telnet	 0.1	Author: accdias@sst.com.br
 #		usrhiper_snmp    1.0    Author: igor@ipass.net
 #		multitech_snmp   1.0    Author: ehonzay@willmar.com
 #		netserver_telnet 1.0	Author: mts@interplanet.es
-#		versanet_snmp    1.0    Author: support@versanetcomm.com
 #
 #	Config: $debug is the file you want to put debug messages in
 #		$snmpget is the location of your ``snmpget'' program
-#		$snmpwalk is the location of your ``snmpwalk'' program
-#		$rusers is the location of your ``rusers'' program
 #		$naspass is the location of your NAS admin password file
 #
+#$debug   = '';
+$debug	 = '/var/log/checkrad.log';
 
-$prefix		= "/usr/local";
-$localstatedir	= "/var";
-$logdir		= "${localstatedir}/log";
-$sysconfdir	= "/etc";
-$raddbdir	= "${sysconfdir}/raddb";
+$snmpget = '/usr/bin/snmpget';
+$naspass = '/etc/raddb/naspasswd';
 
-$debug		= "";
-#$debug		= "$logdir/checkrad.log";
-
-$snmpget	= "/usr/bin/snmpget";
-$snmpwalk	= "/usr/bin/snmpwalk";
-$rusers		= "/usr/bin/rusers";
-$naspass	= "$raddbdir/naspasswd";
+$livingston_snmpread = "innercitesnmp";
 
 #
 #	PM3:	$lv_offs is where the last S port is before one or two
@@ -214,29 +199,6 @@ sub snmpget {
 	$ret;
 }
 
-#
-#	Strip domains, prefixes and suffixes from username
-#	
-#	Known prefixes: (P)PP, (S)LIP e (C)SLIP
-#	Known suffixes: .ppp, .slip e .cslip
-#
-#	Author: Antonio Dias of SST Internet <accdias@sst.com.br>
-#
-sub strip_username {
-	my ($user) = @_;
-	#
-	#	Trim white spaces.
-	#
-	$user =~ s/^\s*(.*?)\s*$/$1/;
-	#
-	#	Strip out domains, prefix and suffixes
-	#
-	$user =~ s/\@(.)*$//;
-	$user =~ s/^[PSC]//;
-	$user =~ s/\.(ppp|slip|cslip)$//;
-	$user;
-}
-
 #
 #	See if the user is logged in using the Livingston MIB.
 #	We don't check the username but the session ID.
@@ -249,7 +211,7 @@ sub livingston_snmp {
 	#	is greater than 29, substract 2 (S30 and S31 don't exist).
 	#	You might need to change this to 23 and 1 for the USA.
 	#
-	$_ = snmpget($ARGV[1], $ARGV[5], "$lvm.3.2.1.1.1.2.5");
+	$_ = snmpget($ARGV[1], $livingston_snmpread, "$lvm.3.2.1.1.1.2.5");
 	/S([0-9]+)/;
 	$xport = $1 + 0;
 	$portidx = $ARGV[2] + (5 - $xport);
@@ -261,7 +223,7 @@ sub livingston_snmp {
 	#
 	#	Now get the session id from the terminal server.
 	#
-	$sessid = snmpget($ARGV[1], $ARGV[5], "$lvm.3.2.1.1.1.5.$portidx");
+	$sessid = snmpget($ARGV[1], $livingston_snmpread, "$lvm.3.2.1.1.1.5.$portidx");
 
 	print LOG "  session id at port S$ARGV[2]: $sessid\n" if ($debug);
 
@@ -273,7 +235,7 @@ sub livingston_snmp {
 #
 $csm	 = '.iso.org.dod.internet.private.enterprises.9';
 sub cisco_snmp {
-	$login = snmpget($ARGV[1], $ARGV[5], "$csm.2.9.2.1.18.$ARGV[2]");
+	$login = snmpget($ARGV[1], "public", "$csm.2.9.2.1.18.$ARGV[2]");
 
 	print LOG "  user at port S$ARGV[2]: $login\n" if ($debug);
 
@@ -285,11 +247,10 @@ sub cisco_snmp {
 #
 #       Author: Eric Honzay of Bennett Office Products <ehonzay@willmar.com>
 #
-$msm    = '.iso.org.dod.internet.private.enterprises.995';
 sub multitech_snmp {
 	my $temp = $ARGV[2] + 1;
 
-        $login = snmpget($ARGV[1], $ARGV[5], "$msm.2.31.1.1.1.$temp");
+        $login = snmpget($ARGV[1], "public", "$msm.2.31.1.1.1.$temp");
         print LOG " user at port S$ARGV[2]: $login\n" if ($debug);
 
         ($login eq $ARGV[3]) ? 1 : 0;
@@ -338,55 +299,6 @@ sub max40xx_finger {
 	close FD;
 }
 
-#
-#	Check an Ascend Max4000 or similar model via SNMP
-#
-#	Note: Not all software revisions support finger
-#	      You may also need to enable the finger option.
-#
-#	Author: Blaz Zupan <blaz@gold.amis.net>
-#
-$asm	 = '.iso.org.dod.internet.private.enterprises.529';
-sub max40xx_snmp {
-	$sess_id = hex $ARGV[4];
-	$login = snmpget($ARGV[1], $ARGV[5], "$asm.12.3.1.4.$sess_id");
-
-	print LOG "  user at port S$ARGV[2]: $login\n" if ($debug);
-
-	($login eq $ARGV[3]) ? 1 : 0;
-}
-
-#
-#	Check an Ascend Max4000 or similar model via SNMP
-#
-#	Author: Blaz Zupan of Medinet <blaz@amis.net>
-#
-$asm   = '.iso.org.dod.internet.private.enterprises.529';
-sub ascend_snmp {
-	my $sess_id;
-	my $l1, $l2;
-
-	$l1 = '';
-	$l2 = '';
-
-	#
-	#	If it looks like hex, only try it as hex,
-	#	otherwise try it as both decimal and hex.
-	#
-	$sess_id = $ARGV[4];
-	if ($sess_id !~ /^0/ && $sess_id !~ /[a-f]/i) {
-		$l1 = snmpget($ARGV[1], $ARGV[5], "$asm.12.3.1.4.$sess_id");
-	}
-	$sess_id = hex $ARGV[4];
-	$l2 = snmpget($ARGV[1], $ARGV[5], "$asm.12.3.1.4.$sess_id");
-
-	print LOG "  user at port S$ARGV[2]: $l1 (dec)\n" if ($debug && $l1);
-	print LOG "  user at port S$ARGV[2]: $l2 (hex)\n" if ($debug && $l2);
-
-	(($l1 && $l1 eq $ARGV[3]) || ($l2 && $l2 eq $ARGV[3])) ? 1 : 0;
-}
-  
-
 #
 #	See if the user is logged in using the portslave finger.
 #
@@ -558,200 +470,92 @@ sub tc_tccheck {
 }
 
 #
-#	Check a Cyclades PathRAS via telnet
-#
-#	Version: 1.2
-#
-#	Author: Antonio Dias of SST Internet <accdias@sst.com.br>
-#
-sub cyclades_telnet {
+#	See if the user is already logged-in at the Cyclades PathRAS.
+#	(this routine by Antonio Dias <accdias@sst.com.br> based on
+#	tc_tccheck by Alexis C. Villalon <alexisv@compass.com.ph>).
+#	You must have the Net::Telnet module from CPAN for this to work.
+#	You must also have your /etc/raddb/naspasswd made up.
+#	Tested with PathRAS firmware 1.1.9g.
+# 
+sub pathras_telnet {
 	#
 	#	Localize all variables first.
 	#
-	my ($pr, $pr_login, $pr_passwd, $pr_prompt, $endlist, @list, $port, $user);
-	#
-	#	This variable must match PathRAS' command prompt 
-	#	string as entered in menu option 6.2.
-	#	The value below matches the default command prompt.
-	#
-	$pr_prompt = '/Select option ==\>$/i';
+	my ($ts, $terminalserver, $log, $login, $pass, $password);
+	my ($telnet, $curprompt, $curline, $ok);
+	my (@curlines, $user, $port);
 
-	#
-	#	This variable match the end of userslist.
-	#
-	$endlist = '/Type \<enter\>/i';
-
-	#
-	#	Do we have Net::Telnet installed?
-	#
 	return 2 unless (check_net_telnet());
 
-	#
-	#	Get login name and password for NAS 
-	#	from $naspass file.
-	#
-	($pr_login, $pr_passwd) = naspasswd($ARGV[1], 1);
+	$terminalserver = $ARGV[1];
+	($login, $password) = naspasswd($terminalserver, 1);
+	return 2 if ($password eq "");
 
 	#
 	#	Communicate with PathRAS using Net::Telnet, then access
-	#	menu option 6.8 to see who are logged in.
-	#	Based on PathRAS firmware version 1.2.3
+	#	menu option 6.8 to see who are logged in. This assumes 
+	#	you are using the default Prompt String (menu option 6.2)
+	#	and is based on PathRAS firmware version 1.1.9g
+	# 
 	#
-	$pr = new Net::Telnet (
-		Timeout		=> 10,
-		Host		=> $ARGV[1],
-		ErrMode		=> 'return'
-	) || return 2;
-
+	$telnet = new Net::Telnet (Timeout => 10);
+	$telnet->open($terminalserver);
 	#
-	#	Force PathRAS shows its banner.
+	#	Dunno why but PathRAS only issue its banner and 
+	#	the login prompt after receive a "CR" 
 	#
-	$pr->break();
-
+	$telnet->print("");
 	#
 	#	Log on PathRAS
 	#
-	if ($pr->waitfor(Match => '/login : $/i') == 1) {
-		$pr->print($pr_login);
-	} else { 
-		print LOG " Error: sending login name to PathRAS\n" if ($debug);
-		$pr->close;
-		return 2;	
-	}
+	$telnet->waitfor('/login :.*$/');
+	$telnet->print($login);
+	$telnet->waitfor('/password :.*$/');
+	$telnet->print($password);
+	#
+	#	Wait for PathRAS default Prompt String "==> "
+	#	and access menu option 6.8 "Show Actives Ports"
+	#
+	$telnet->waitfor('/==\> .*$/');
+	$telnet->print("6");
+	$telnet->waitfor('/==\> .*$/');
+	$telnet->print("8");
 
-	if ($pr->waitfor(Match => '/password : $/i') == 1) {
-		$pr->print($pr_passwd);
-	} else { 
-		print LOG " Error: sending password to PathRAS.\n" if ($debug);
-		$pr->close;
-		return 2;	
-	}
-
-	$pr->print();
+	while ($curprompt ne "==> ") {
+		($curline, $curprompt) = $telnet->waitfor
+			(String => "Type <enter> to return",
+			 String => "==> ",
+			 Timeout => 10);
+		$ok = $telnet->print("");
+		push @curlines, split(/^/m, $curline);
+	};
 
+	$telnet->close;
 	#
-	#	Access menu option 6 "PathRAS Management"
+	#	Telnet closed.  We got the info.  Let's examine it.
 	#
-	if ($pr->waitfor(Match => $pr_prompt) == 1) {
-		$pr->print('6');
-	} else { 
-		print LOG "  Error: acessing menu option '6'.\n" if ($debug);
-		$pr->close;
-		return 2;
-	}
-	#
-	#	Access menu option 8 "Show Active Ports"
-	#
-	if ($pr->waitfor(Match => $pr_prompt) == 1) {
-		@list = $pr->cmd(String => '8', Prompt => $endlist);
-	} else { 
-		print LOG "  Error: acessing menu option '8'.\n" if ($debug);
-		$pr->close;
-		return 2;
-	}
-	#
-	#	Since we got the info we want, let's close 
-	#	the telnet session
-	#
-	$pr->close;
-
-	#
-	#	Lets examine the userlist stored in @list
-	#
-	foreach(@list) {
-		#
-		#	We are interested in active sessions only
-		#
-		if (/Active/i) {
+	foreach(@curlines) {
+		if (m/PPP Active|SLIP Active/) {
 			($port, $user) = split;
 			#
-			#	Strip out any prefix, suffix and
-			#	realm from $user check to see if
-			#	$ARGV[3] matches.
+			# Strip out any prefixes and suffixes 
+			# from the username
 			#
-			if($ARGV[3] eq strip_username($user)) {
-				print LOG "  User '$ARGV[3]' found on '$ARGV[1]:$port'.\n" if ($debug);
+			$user =~ s/^[PSC]//;
+			$user =~ s/\.(ppp|slip|cslip)$//;
+			#
+			# Check to see if $user is already connected
+			#
+			if ($user eq $ARGV[3]) {
+				print LOG "  $user matches $ARGV[3] " .
+					"on port $port" if ($debug);
 				return 1;
-			}
-		}
-	}
-	print LOG "  User '$ARGV[3]' not found on '$ARGV[1]'.\n" if ($debug);
-   	0;
-}
-
-#
-#	Check a Patton 2800 via snmp
-#
-#	Version: 1.0
-#
-#	Author: Antonio Dias of SST Internet <accdias@sst.com.br>
-#
-sub patton_snmp {
-   my($oid);
-
-   $oid = '.1.3.6.1.4.1.1768.5.100.1.40.' . hex $ARGV[4];
-   #
-   # Check if the session still active
-   # 
-   if (snmpget($ARGV[1], $ARGV[5], "$oid") == 0) {
-      print LOG "  Session $ARGV[4] still active on NAS " . 
-      	"$ARGV[1], port $ARGV[2], for user $ARGV[3].\n" if ($debug);
-      return 1;
-   }
-   0;
-}
-
-#
-#      Check a Digitro BXS via rusers
-#
-#      Version: 1.1
-#
-#      Author: Antonio Dias of SST Internet <accdias@sst.com.br>
-#
-sub digitro_rusers {
-   my ($ret);
-   local $_;
-
-   if (-e $rusers && -x $rusers) {
-      #
-      # Get a list of users logged in via rusers
-      #
-      $_ =`$rusers $ARGV[1]`;
-      $ret = ((/$ARGV[3]/) ? 1 : 0);
-   } else {
-      print LOG "   Error: can't execute $rusers\n" if $debug;
-      $ret = 2;
-   }
-   $ret;
-}
-
-#
-#	Check Cyclades PR3000 and PR4000 via SNMP
-#
-#	Version: 1.0
-#
-#	Author: Antonio Dias of SST Internet <accdias@sst.com.br>
-#
-sub cyclades_snmp {
-   my ($oid, $ret);
-   local $_;
-   
-   $oid = ".1.3.6.1.4.1.2925.3.3.6.1.1.2";
-
-   if (-e $snmpwalk && -x $snmpwalk) { 	
-      #
-      # Get a list of logged in users via snmpwalk
-      #
-      # I'm looking for a way to do this using SNMP_Session
-      # module. Any help would be great.
-      #
-      $_ = `$snmpwalk $ARGV[1] public $oid`;
-      $ret = ((/$ARGV[3]/) ? 1 : 0);
-   } else {
-      print LOG "   Error: can't execute $snmpwalk\n" if $debug;
-      $ret = 2;
-   }
-   $ret;
+			};
+		};
+	};
+	print LOG 
+	"  $ARGV[3] not found on PathRAS logged users list " if ($debug);
+	0;
 }
 
 #
@@ -766,12 +570,8 @@ sub usrhiper_snmp {
 	my($oidext) = $ARGV[2] + 1256;
 	my ($login);
 
-	$login = snmpget($ARGV[1], $ARGV[5], "$usrm.4.10.1.1.18.$oidext");
-	#($login) = /^.*\"([^"]+)".*$/;
-	if ($login =~ /\"/) {
-		$login =~ /^.*\"([^"]+)\"/;
-		$login = $1;
-	}
+	$login = snmpget($ARGV[1], "public", "$usrm.4.10.1.1.18.$oidext");
+	($login) = /^.*\"([^"]+)".*$/;
 
 	print LOG "  user at port S$ARGV[2]: $login\n" if ($debug);
 
@@ -857,41 +657,17 @@ sub usrnet_telnet {
 	0;
 }
 
-#
-#	Versanet's Perl Script Support:
-#
-#	___ versanet_snmp 1.0 by support@versanetcomm.com ___ July 1999
-#	Versanet Enterprise MIB Base: 1.3.6.1.4.1.2180
-#   
-#	VN2001/2002 use slot/port number to locate modems. To use snmp get we
-#	have to translate the original port number into a slot/port pair.
-#
-$vsm     = '.iso.org.dod.internet.private.enterprises.2180';
-sub versanet_snmp {
-        
-	print LOG "argv[2] = $ARGV[2] " if ($debug);
-	$port = $ARGV[2]%8;
-	$port = 8 if ($port eq 0);	  
-	print LOG "port = $port " if ($debug);
-	$slot = (($ARGV[2]-$port)/8)+1;
-	print LOG "slot = $slot" if ($debug);
-	$loginname = snmpget($ARGV[1], $ARGV[5], "$vsm.27.1.1.3.$slot.$port");
-
-	print LOG "  user at slot $slot port $port: $loginname\n" if ($debug);	  ($loginname eq $ARGV[3]) ? 1 : 0;	
-}
-
-
 if ($debug) {
 	open(LOG, ">>$debug");
 	$now = localtime;
 	print LOG "$now checkrad @ARGV\n";
 }
 
-if ($#ARGV != 5) {
+if ($#ARGV != 4) {
 	print LOG "Usage: checkrad nas_type nas_ip " .
-			"nas_port login session_id snmp_community\n" if ($debug);
+			"nas_port login session_id\n" if ($debug);
 	print STDERR "Usage: checkrad nas_type nas_ip " .
-			"nas_port login session_id snmp_community\n";
+			"nas_port login session_id\n";
 	close LOG if ($debug);
 	exit(2);
 }
@@ -906,30 +682,16 @@ if ($ARGV[0] eq 'livingston') {
 	$ret = &computone_finger;
 } elsif ($ARGV[0] eq 'max40xx') {
 	$ret = &max40xx_finger;
-} elsif ($ARGV[0] eq 'max40xx_snmp') {
-	$ret = &max40xx_snmp;
-} elsif ($ARGV[0] eq 'ascend') {
-	$ret = &ascend_snmp;
 } elsif ($ARGV[0] eq 'portslave') {
 	$ret = &portslave_finger;
 } elsif ($ARGV[0] eq 'tc') {
 	$ret = &tc_tccheck;
 } elsif ($ARGV[0] eq 'pathras') {
-	$ret = &cyclades_telnet;
-} elsif ($ARGV[0] eq 'pr3000') {
-	$ret = &cyclades_snmp;
-} elsif ($ARGV[0] eq 'pr4000') {
-	$ret = &cyclades_snmp;
-} elsif ($ARGV[0] eq 'patton') {
-	$ret = &patton_snmp;
-} elsif ($ARGV[0] eq 'digitro') {
-	$ret = &digitro_rusers;
+	$ret = &pathras_telnet;
 } elsif ($ARGV[0] eq 'usrhiper') {
 	$ret = &usrhiper_snmp;
 } elsif ($ARGV[0] eq 'netserver') {
 	$ret = &usrnet_telnet;
-} elsif ($ARGV[0] eq 'versanet'){
-        $ret = &versanet_snmp;
 } elsif ($ARGV[0] eq 'other') {
 	$ret = 1;
 } else {
